@@ -1,6 +1,7 @@
 """Authentication library, implemented by users of the API."""
 import logging
 from abc import ABC, abstractmethod
+
 import aiohttp
 from google.auth.credentials import Credentials
 
@@ -34,5 +35,5 @@ class AbstractAuth(ABC):
         access_token = await self.async_get_access_token()
         headers["authorization"] = f"Bearer {access_token}"
         url = f"{self._host}/{url}"
-        logging.debug(f"request[{method}]={url}")
+        logging.debug("request[%s]=%s", method, url)
         return await self._websession.request(method, url, **kwargs, headers=headers)
